@@ -104,8 +104,7 @@ FormatCurrency: {{ 512.5032 | lang.FormatCurrency 2 "USD" }}
 FormatAccounting: {{ 512.5032 | lang.FormatAccounting 2 "NOK" }}
 FormatNumberCustom: {{ lang.FormatNumberCustom 2 12345.6789 }}
 
-# We renamed this to FormatNumberCustom in 0.87.0.
-NumFmt: {{ -98765.4321 | lang.NumFmt 2 }}
+
 
 	
 `)
@@ -120,7 +119,6 @@ FormatCurrency: $512.50
 FormatAccounting: NOK512.50
 FormatNumberCustom: 12,345.68
         
-NumFmt: -98,765.43
 `,
 	)
 
@@ -131,8 +129,6 @@ FormatCurrency: 512,50 USD
 FormatAccounting: 512,50 kr
 FormatNumberCustom: 12,345.68
 
-# We renamed this to FormatNumberCustom in 0.87.0.
-NumFmt: -98,765.43
 `)
 }
 
