@@ -22,7 +22,6 @@ type lexerShortcodeState struct {
 	elementStepNum     int             // step number in element
 	paramElements      int             // number of elements (name + value = 2) found first
 	openShortcodes     map[string]bool // set of shortcodes in open state
-
 }
 
 // Shortcode syntax
@@ -84,7 +83,6 @@ func lexShortcodeRightDelim(l *pageLexer) stateFunc {
 // 5. `param`
 // 6. param=`123`
 func lexShortcodeParam(l *pageLexer, escapedQuoteStart bool) stateFunc {
-
 	first := true
 	nextEq := false
 
@@ -138,7 +136,6 @@ func lexShortcodeParam(l *pageLexer, escapedQuoteStart bool) stateFunc {
 
 	l.emit(tScParam)
 	return lexInsideShortcode
-
 }
 
 func lexShortcodeParamVal(l *pageLexer) stateFunc {
@@ -187,7 +184,7 @@ Loop:
 					l.backup()
 					break Loop
 				} else if openQuoteFound {
-					// the coming quoute is inside
+					// the coming quote is inside
 					escapedInnerQuoteFound = true
 					escapedQuoteState = 1
 				}
@@ -325,6 +322,7 @@ func lexInsideShortcode(l *pageLexer) stateFunc {
 		}
 		l.closingState++
 		l.isInline = false
+		l.elementStepNum = 0
 		l.emit(tScClose)
 	case r == '\\':
 		l.ignore()
@@ -356,7 +354,6 @@ func (l *pageLexer) currentLeftShortcodeDelim() []byte {
 		return leftDelimScWithMarkup
 	}
 	return leftDelimScNoMarkup
-
 }
 
 func (l *pageLexer) currentRightShortcodeDelim() []byte {
